import { isValidVariableIdentifier } from './values/variable-placeholder.js';
import { isValidGraphqlType } from './variable-type.js';
function ensureValidVariableDefinition(variableDefinition) {
    const [variableName, variableType] = variableDefinition;
    if (!isValidVariableIdentifier(variableName)) {
        throw new Error(`Variable name "${variableName}" is not a valid GraphQL variable name`);
    }
    if (!isValidGraphqlType(variableType)) {
        throw new Error(`Type "${variableType}" for variable "${variableName}" is invalid`);
    }
}
function serializeVariableDefinitionPair(variableDefinition) {
    const [variableName, variableType] = variableDefinition;
    return `${variableName}: ${variableType}`;
}
export function serializeVariableDefinitions(definitions) {
    const entries = Object.entries(definitions);
    if (entries.length === 0) {
        return '';
    }
    entries.forEach(ensureValidVariableDefinition);
    const serializedEntries = entries.map(serializeVariableDefinitionPair);
    return `(${serializedEntries.join(', ')})`;
}
//# sourceMappingURL=variable-definition.js.map